@@ -19,7 +19,7 @@ def update_or_create_herre(decoded):
             user.roles = decoded["roles"]
             user.save()
         except LokUser.DoesNotExist:
-            user = LokUser(email=decoded["email"])
+            user = LokUser(email=decoded["email"], username=f"Lok {decoded['email']}")
             user.roles = decoded["roles"]
             user.set_unusable_password()
             user.save()
